@@ -23,6 +23,7 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/blang/semver/v4"
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
 	"github.com/pkg/errors"
@@ -56,6 +57,34 @@ func TestName(t *testing.T) {
 	}
 }
 
+func TestDefaultDockerSocketPath(t *testing.T) {
+	var tests = []struct {
+		version string
+		want    string
+	}{
+		{"1.20.0", InternalDockerCRISocket},
+		{"1.21.3", InternalDockerCRISocket},
+		{"1.23.0", InternalDockerCRISocket},
+		{"1.24.0-alpha.0", ExternalDockerCRISocket},
+		{"1.24.0-beta.0", ExternalDockerCRISocket},
+		{"1.24.6", ExternalDockerCRISocket},
+	}
+	for _, tc := range tests {
+		runtime := "docker"
+		version := semver.MustParse(tc.version)
+		t.Run(runtime, func(t *testing.T) {
+			r, err := New(Config{Type: runtime, KubernetesVersion: version})
+			if err != nil {
+				t.Fatalf("New(%s): %v", tc.version, err)
+			}
+			got := r.SocketPath()
+			if got != tc.want {
+				t.Errorf("SocketPath(%s) = %q, want: %q", tc.version, got, tc.want)
+			}
+		})
+	}
+}
+
 func TestImageExists(t *testing.T) {
 	var tests = []struct {
 		runtime string
@@ -244,6 +273,10 @@ func (f *FakeRunner) Remove(assets.CopyableFile) error {
 	return nil
 }
 
+func (f *FakeRunner) ReadableFile(sourcePath string) (assets.ReadableFile, error) {
+	return nil, nil
+}
+
 func (f *FakeRunner) dockerPs(args []string) (string, error) {
 	// ps -a --filter="name=apiserver" --format="{{.ID}}"
 	if args[1] == "-a" && strings.HasPrefix(args[2], "--filter") {
